
(_installation)=
# Installation

`skretrieval` can be installed through

    pip install skretrieval


# Tested Platforms
The latest version of `skretrieval` is tested on the following platforms, although other versions may
also work.

|   | macOS Intel | macOS Apple Silicon | Windows 64bit | manylinux x86_64 | manylinux aarch64
|---------------|----|-----|-----|-----|
| CPython 3.11  | ✅ | ✅  | ✅  | ✅  | ✅  |
| CPython 3.12  | ✅ | ✅  | ✅  | ✅  | ✅  |
